summaryrefslogtreecommitdiffstats
path: root/kdf/kdfwidget.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kdf/kdfwidget.cpp')
-rw-r--r--kdf/kdfwidget.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/kdf/kdfwidget.cpp b/kdf/kdfwidget.cpp
index c6e05af..9b0d11a 100644
--- a/kdf/kdfwidget.cpp
+++ b/kdf/kdfwidget.cpp
@@ -198,11 +198,11 @@ void KDFWidget::settingsChanged( void )
/***************************************************************************
* writes the KConfig
**/
void KDFWidget::applySettings( void )
{
- KConfig &config = *kapp->config();
+ TDEConfig &config = *kapp->config();
config.setGroup("KDiskFree");
if( GUI )
@@ -223,7 +223,7 @@ void KDFWidget::applySettings( void )
/***************************************************************************
* reads the KConfig
**/
void KDFWidget::loadSettings( void )
{
@@ -231,7 +231,7 @@ void KDFWidget::loadSettings( void )
if(GUI)
{
- KConfig &config = *kapp->config();
+ TDEConfig &config = *kapp->config();
config.setGroup("KDiskFree");
for( uint i=0; i<mTabProp.size(); i++ )
{
@@ -198,11 +198,11 @@ void KDFWidget::settingsChanged( void )
/***************************************************************************
- * writes the KConfig
+ * writes the TDEConfig
**/
void KDFWidget::applySettings( void )
@@ -223,7 +223,7 @@ void KDFWidget::applySettings( void )
/***************************************************************************
- * reads the KConfig
+ * reads the TDEConfig
**/
void KDFWidget::loadSettings( void )